/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：InoutDao.java
 * 创建日期：2021年10月21日 上午9:12:44
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.Inout;

import jodd.util.StringUtil;

/**
 * 类描述   农村居民收入与支出Dao层
 * @author mt.W
 * @since 2021年10月21日
 */
@Repository
public class InoutDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述   保存年度居民平均收入与支出信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param t
	 * @return
	 */
	public int addInoutInfo(Inout t){
		String sql = "insert into ncjj_inout(orgid,year,sy,zc,createTime,createUser) values(?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{t.getOrgid(),t.getYear(),t.getSy(),t.getZc(),t.getCreateTime(),t.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述   修改年度居民平均收入与支出信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param t
	 * @return
	 */
	public int editInoutInfo(Inout t){
		String sql = "update ncjj_inout set year = ? ,sy=?,zc=?,updateTime=?,updateUser=? where id = ? ";
		return jdbc.update(sql,new Object[]{t.getYear(),t.getSy(),t.getZc(),t.getUpdateTime(),t.getUpdateUser(),t.getId()});
	}
	/**
	 * 
	 * 方法描述
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String,Object>> getInoutRecordList(int start,int limit,String year,String orgid){
		String sql = "select n.*,o.name orgname from ncjj_inout n left join orgdept o on o.id = n.orgid where orgid like '"+orgid+"%'   ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		sql += " order by year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述
	 * @author mt.W
	 * @since 2021年10月22日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String,Object>> getInoutRecordList(String year,String orgid){
		String sql = "select t.*,o.name orgname from ncjj_inout t  "
				+ " left join orgdept o on o.id = t.orgid "
				+ " where t.orgid like '"+orgid+"%'";
		if(StringUtil.isNotEmpty(year)){
			sql += " and t.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getInoutRecordCount(String year,String orgid){
		String sql = "select count(id) from ncjj_inout where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述   删除居民收入和支出信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param id
	 * @return
	 */
	public int deleteInoutRecord(String id){
		String sql = "delete from ncjj_inout where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述  检查年份是否已存在
	 * @author mt.W
	 * @since 2021年10月22日
	 * @param z
	 * @return
	 */
	public int checkIfExistByYearAndOrg(Inout z){
		String sql="select count(id) from ncjj_inout where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
