/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：JinChuKouDao.java
 * 创建日期：2021年10月21日 下午3:07:54
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.JinChuKou;

import jodd.util.StringUtil;

/**
 * 类描述
 * @author mt.W
 * @since 2021年10月21日
 */
@Repository
public class JinChuKouDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述  查询进出口信息记录
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param start
	 * @param limit
	 * @param orgid
	 * @param year
	 * @return
	 */
	public List<Map<String, Object>> getJinChuKouRecordList(int start,int limit,String year,String orgid){
		String sql = "select j.*,o.name orgname from ncjj_jck j left join orgdept o on o.id = j.orgid  where j.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and j.year = '"+year+"' ";
		}
		sql += " order by j.year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询进出口信息记录
	 * @author mt.W
	 * @since 2021年10月22日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String,Object>> getJinChuKouRecordList(String year,String orgid){
		String sql = "select k.*,o.name orgname from ncjj_jck k "
				+ " left join orgdept o on o.id = k.orgid where k.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述     查询进出口记录数
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param orgid
	 * @param year
	 * @return
	 */
	public int getJinChuKouRecordCount(String year,String orgid){
		String sql = "select count(id) from ncjj_jck where orgid like '"+orgid+"%'  ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql,Integer.class);
	}
	/**
	 * 
	 * 方法描述    新增进出口贸易信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param j
	 * @return
	 */
	public int addJinChuKouInfo(JinChuKou j){
		String sql = "insert into ncjj_jck(orgid,year,dwcp_in,dwcp_out,zwcp_in,zwcp_out,yzjl_in,yzjl_out,yczp_int,yczp_out,"
				+ "qt_in,qt_out,inzj,outzj,inoutzj,createTime,createUser)"
				+ " values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{j.getOrgid(),j.getYear(),j.getDwcp_in(),j.getDwcp_out(),j.getZwcp_in(),j.getZwcp_out(),
				j.getYzjl_in(),j.getYzjl_out(),j.getYczp_int(),j.getYczp_out(),j.getQt_in(),j.getQt_out(),
				j.getInzj(),j.getOutzj(),j.getInoutzj(),j.getCreateTime(),j.getCreateUser()});
	}
	/**
	 *  
	 * 方法描述    修改进出口贸易信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param j
	 * @return
	 */
	public int editJinChuKouInfo(JinChuKou j){
		String sql = "update ncjj_jck set dwcp_in=?,dwcp_out=?,zwcp_in=?,zwcp_out=?,yzjl_in=?,yzjl_out=?,yczp_int=?,yczp_out=?,"
				+ "qt_in=?,qt_out=?,inzj=?,inoutzj=?,updateTime=?,updateUser=?,outzj=? where id = ? ";
		return jdbc.update(sql,new Object[]{j.getDwcp_in(),j.getDwcp_out(),j.getZwcp_in(),j.getZwcp_out(),j.getYzjl_in(),j.getYzjl_out(),j.getYczp_int(),j.getYczp_out(),
				j.getQt_in(),j.getQt_out(),j.getInzj(),j.getInoutzj(),j.getUpdateTime(),j.getUpdateUser(),j.getOutzj(),j.getId()});
	}
	/**
	 * 
	 * 方法描述  删除进出口贸易信息
	 * @author mt.W
	 * @since 2021年10月21日
	 * @param id
	 * @return
	 */
	public int deleteJinChuKouInfo(String id){
		String sql = "delete from ncjj_jck where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述  检查年份是否已存在
	 * @author mt.W
	 * @since 2021年10月22日
	 * @param z
	 * @return
	 */
	public int checkIfExistByYearAndOrg(JinChuKou z){
		String sql="select count(id) from ncjj_jck where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
