/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：NyzbYdhxhDao.java
 * 创建日期：2021年10月25日 下午3:40:53
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.NyzbYdhxh;

import jodd.util.StringUtil;

/**
 * 类描述  农业技术装备统计指标-用电与农业化学化Dao
 * @author mt.W
 * @since 2021年10月25日
 */
@Repository
public class NyzbYdhxhDao {

	@Autowired
	private JdbcTemplate jdbc;
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String,Object>> getRecordList(int start,int limit,String year,String orgid){
		String sql = "select n.*,o.name orgname from nyzb_ydhxh n left join orgdept o on o.id = n.orgid where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and n.year = '"+year+"' ";
		}
		sql += " order by year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String,Object>> getRecordList(String year,String orgid){
		String sql = "select n.*,o.name orgname from nyzb_ydhxh n left join orgdept o on o.id = n.orgid where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and n.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述  查询记录数
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getRecordCount(String year,String orgid){
		String sql = "select count(id) from nyzb_ydhxh where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述  新增记录
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param n
	 * @return
	 */
	public int addRecord(NyzbYdhxh n){
		String sql = "insert into nyzb_ydhxh(year,orgid,ncydl,nyhfsyl,nyslbm,df,lf,jf,fhf,createTime,createUser) values(?,?,?,?,?,?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{n.getYear(),n.getOrgid(),n.getNcydl(),n.getNyhfsyl(),n.getNyslbm(),n.getDf(),n.getLf(),n.getJf(),n.getFhf(),n.getCreateTime(),n.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述  修改记录
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param n 
	 * @return
	 */
	public int editRecord(NyzbYdhxh n){
		String sql = "update nyzb_ydhxh set year=?,ncydl=?,nyhfsyl=?,nyslbm=?,df=?,lf=?,fhf=?,updateTime=?,updateUser=? where id = ?";
		return jdbc.update(sql,new Object[]{n.getYear(),n.getNcydl(),n.getNyhfsyl(),n.getNyslbm(),n.getDf(),n.getLf(),n.getFhf(),n.getUpdateTime(),n.getUpdateUser(),n.getId()});
	}
	/**
	 * 
	 * 方法描述   删除记录
	 * @author mt.W
	 * @since 2021年10月25日
	 * @param id
	 * @return
	 */
	public int deleteRecord(String id){
		String sql = "delete from nyzb_ydhxh where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述  检查年份是否已存在
	 * @author mt.W
	 * @since 2021年10月22日
	 * @param z
	 * @return
	 */
	public int checkIfExistByYearAndOrg(NyzbYdhxh z){
		String sql="select count(id) from nyzb_ydhxh where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
