/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：YyzbHsyzblDao.java
 * 创建日期：2021年10月26日 下午3:50:46
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.YyzbYzbl;

import jodd.util.StringUtil;

/** 
 * 类描述  渔业统计指标-海水养殖与捕捞 dao
 * @author mt.W
 * @since 2021年10月26日
 */
@Repository
public class YyzbHsyzblDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述   查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(int start,int limit,String year,String orgid){
		String sql = "select z.*,o.name orgname from yyzb_hsyzbl z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		sql += " order by z.year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(String year,String orgid){
		String sql = "select z.*,o.name orgname from yyzb_hsyzbl z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述   查询记录数量
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getRecordCount(String year,String orgid){
		String sql = "select count(id) from yyzb_hsyzbl where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述   新增记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int addRecord(YyzbYzbl z){
		String sql = "insert into yyzb_hsyzbl(year,orgid,ylyz,ylbl,ylyzmj,jkyz,jkbl,jkyzmj,blyz,blbl,blyzmj,zyz,zbl,zyzmj,createTime,createUser)"
				+ " values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getOrgid(),z.getYlyz(),z.getYlbl(),z.getYlyzmj(),z.getJkyz(),z.getJkbl(),z.getJkyzmj(),
				z.getBlyz(),z.getBlbl(),z.getBlyzmj(),z.getZyz(),z.getZbl(),z.getZyzmj(),z.getCreateTime(),z.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述   修改记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int editRecord(YyzbYzbl z){
		String sql = "update yyzb_hsyzbl set year=?,ylyz=?,ylbl=?,ylyzmj=?,jkyz=?,jkbl=?,jkyzmj=?,blyz=?,blbl=?,blyzmj=?,zyz=?,zbl=?,zyzmj=?,updateTime=?,updateUser=? where id=?";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getYlyz(),z.getYlbl(),z.getYlyzmj(),z.getJkyz(),z.getJkbl(),z.getJkyzmj(),
				z.getBlyz(),z.getBlbl(),z.getBlyzmj(),z.getZyz(),z.getZbl(),z.getZyzmj(),z.getUpdateTime(),z.getUpdateUser(),z.getId()});
	}
	/**
	 * 
	 * 方法描述  删除记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param id
	 * @return
	 */
	public int deleteRecord(String id){
		String sql = "delete from yyzb_hsyzbl where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	public int checkIfExistByYearAndOrg(YyzbYzbl z){
		String sql="select count(id) from yyzb_hsyzbl where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
