/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：ZzySclDao.java
 * 创建日期：2021年10月26日 下午1:53:32
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.ZzyScl;

import jodd.util.StringUtil;

/**
 * 类描述   种植业指标-蔬菜类统计 Dao
 * @author mt.W
 * @since 2021年10月26日
 */
@Repository
public class ZzySclDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述   查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(int start,int limit,String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_scl z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		sql += " order by z.year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_scl z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述   查询记录数量
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getRecordCount(String year,String orgid){
		String sql = "select count(id) from zzy_scl where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述   新增记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int addRecord(ZzyScl z){
		String sql = "insert into zzy_scl(year,orgid,scbzmj,sczcl,glbzmj,glzcl,bzzmj,zcl,createTime,createUser) "
				+ " values(?,?,?,?,?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getOrgid(),z.getScbzmj(),z.getSczcl(),z.getGlbzmj()
				,z.getGlzcl(),z.getBzzmj(),z.getZcl(),z.getCreateTime(),z.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述   修改记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int editRecord(ZzyScl z){
		String sql = "update  zzy_scl set year=?,scbzmj=?,sczcl=?,glbzmj=?,glzcl=?,bzzmj=?,zcl=?,updateTime=?,updateUser=? where id = ? ";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getScbzmj(),z.getSczcl(),z.getGlbzmj(),z.getGlzcl(),z.getBzzmj(),z.getZcl(),z.getUpdateTime(),z.getUpdateUser(),z.getId()});
	}
	/**
	 * 
	 * 方法描述  删除记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param id
	 * @return
	 */
	public int deleteRecord(String id){
		String sql = "delete from zzy_scl where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述  查询年度数据是否已存在
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int checkIfExistByYearAndOrg(ZzyScl z){
		String sql="select count(id) from zzy_scl where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
